==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectConditional.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectconditional_h
#define objectconditional_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_conditional {
  t_math _math;
  p_module _module;
  int _module_isdefault : 1;
  p_expression _if;
  int _if_isdefault : 1;
  gpointer _then;
  int _then_isdefault : 1;
  gpointer _else;
  int _else_isdefault : 1;
  char* _name;
  int _name_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectExpression.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_conditional_getuid (p_conditional myconditional);
win32_interface gboolean adms_conditional_cmp (p_conditional myconditional,p_conditional refconditional);
win32_interface p_conditional adms_conditional_new_1 (p_module mymodule,p_expression myif,gpointer mythen,gpointer myelse);
#define adms_conditional_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_conditional_free(item)\
{\
  free(item->_name);\
  free(item);\
}
win32_interface p_adms adms_conditional_new_impl (p_adms arguments[]);
win32_interface p_conditional adms_conditional_impl (void* member);
#define adms_conditional(member) ((p_conditional) (member))
#define adms_conditional_new adms_conditional_new_1
#define adms_conditional_isdefault_module(conditional) (adms_conditional(conditional)->_module_isdefault)
#define adms_conditional_valueof_module(conditional) (adms_conditional(conditional)->_module)
#define adms_conditional_isdefault_if(conditional) (adms_conditional(conditional)->_if_isdefault)
#define adms_conditional_valueof_if(conditional) (adms_conditional(conditional)->_if)
#define adms_conditional_isdefault_then(conditional) (adms_conditional(conditional)->_then_isdefault)
#define adms_conditional_valueof_then(conditional) (adms_conditional(conditional)->_then)
#define adms_conditional_isdefault_else(conditional) (adms_conditional(conditional)->_else_isdefault)
#define adms_conditional_valueof_else(conditional) (adms_conditional(conditional)->_else)
#define adms_conditional_isdefault_name(conditional) (adms_conditional(conditional)->_name_isdefault)
#define adms_conditional_valueof_name(conditional) (adms_conditional(conditional)->_name)
#define adms_conditional_valueof_math(conditional) ((p_math)conditional)
#define adms_conditional_valueof_adms(conditional) ((p_adms)conditional)
#define adms_conditional_valueto_module(a,b) ((p_conditional)a)->_module=(b)
win32_interface void adms_conditional_valueto_module_impl (p_conditional myconditional,p_module _module);
#define adms_conditional_valueto_if(a,b) ((p_conditional)a)->_if=(b)
win32_interface void adms_conditional_valueto_if_impl (p_conditional myconditional,p_expression _if);
#define adms_conditional_valueto_then(a,b) ((p_conditional)a)->_then=(b)
win32_interface void adms_conditional_valueto_then_impl (p_conditional myconditional,gpointer _then);
#define adms_conditional_valueto_else(a,b) ((p_conditional)a)->_else=(b)
win32_interface void adms_conditional_valueto_else_impl (p_conditional myconditional,gpointer _else);
#define adms_conditional_valueto_name(a,b) ((p_conditional)a)->_name=(b)
win32_interface void adms_conditional_valueto_name_impl (p_conditional myconditional,char* _name);
#endif /* objectconditional_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectConditional.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectconditional_h
#define objectconditional_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_conditional {
  t_math _math;
  p_module _module;
  int _module_isdefault : 1;
  p_expression _if;
  int _if_isdefault : 1;
  p_adms _then;
  int _then_isdefault : 1;
  p_adms _else;
  int _else_isdefault : 1;
  p_quark _name;
  int _name_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectExpression.h>
#include <admsObject/objectQuark.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_conditional_uid (p_conditional myconditional);
win32_interface int adms_conditional_cmp (p_conditional myconditional,p_conditional refconditional);
win32_interface p_conditional adms_conditional_new(p_module mymodule,p_expression myif,p_adms mythen,p_adms myelse);
win32_interface p_adms adms_conditional_new_impl (p_adms arguments[]);
#define adms_conditional(member) ((p_conditional) (member))
#define adms_conditional_isdefault_module(conditional) (adms_conditional(conditional)->_module_isdefault)
#define adms_conditional_valueof_module(conditional) (adms_conditional(conditional)->_module)
#define adms_conditional_isdefault_if(conditional) (adms_conditional(conditional)->_if_isdefault)
#define adms_conditional_valueof_if(conditional) (adms_conditional(conditional)->_if)
#define adms_conditional_isdefault_then(conditional) (adms_conditional(conditional)->_then_isdefault)
#define adms_conditional_valueof_then(conditional) (adms_conditional(conditional)->_then)
#define adms_conditional_isdefault_else(conditional) (adms_conditional(conditional)->_else_isdefault)
#define adms_conditional_valueof_else(conditional) (adms_conditional(conditional)->_else)
#define adms_conditional_isdefault_name(conditional) (adms_conditional(conditional)->_name_isdefault)
#define adms_conditional_valueof_name(conditional) (adms_conditional(conditional)->_name)
#define adms_conditional_valueof_math(conditional) ((p_math)conditional)
#define adms_conditional_valueof_adms(conditional) ((p_adms)conditional)
win32_interface inline void adms_conditional_valueto_module (p_conditional myconditional,p_module _module);
win32_interface inline void adms_conditional_valueto_if (p_conditional myconditional,p_expression _if);
win32_interface inline void adms_conditional_valueto_then (p_conditional myconditional,p_adms _then);
win32_interface inline void adms_conditional_valueto_else (p_conditional myconditional,p_adms _else);
win32_interface inline void adms_conditional_valueto_name (p_conditional myconditional,p_quark _name);
win32_interface inline void adms_conditional_free(p_conditional myconditional);
#endif /* objectconditional_h */
